@@ -23,6 +23,7 @@
 #include <time.h>
 
 #include "applet-struct.h"
+#include "applet-load-icons.h"
 #include "applet-notifications.h"
 
 
@@ -30,7 +31,11 @@
 CD_APPLET_ON_CLICK_BEGIN
 	if (CD_APPLET_CLICKED_ICON == myIcon)
 	{
-		if (CD_APPLET_MY_ICONS_LIST == NULL)  // repertoire vide, ou illisible, ou non defini.
+		if (! myConfig.bShowFiles)
+		{
+			cairo_dock_fm_launch_uri (myConfig.cDirPath);
+		}
+		else if (CD_APPLET_MY_ICONS_LIST == NULL)  // repertoire vide, ou illisible, ou non defini
 		{
 			cairo_dock_remove_dialog_if_any (myIcon);
 			if (myConfig.cDirPath == NULL)
@@ -39,12 +44,16 @@ CD_APPLET_ON_CLICK_BEGIN
 					8000.,
 					myConfig.iSubdockViewType == 0 ? "same icon" : MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
 			else
+			{
+				gchar *cPath = g_filename_from_uri (myConfig.cDirPath, NULL, NULL);
 				cairo_dock_show_temporary_dialog_with_icon_printf ("%s :\n%s",
 					myIcon, myContainer,
 					4000.,
 					myConfig.iSubdockViewType == 0 ? "same icon" : MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE,
-					myConfig.cDirPath,
+					cPath ? cPath : myConfig.cDirPath,
 					D_("Empty or unreadable folder."));
+				g_free (cPath);
+			}
 		}
 		else
 			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);  // on laisse passer la notification (pour ouvrir le sous-dock au clic).
@@ -172,6 +181,9 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 		gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 		gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
 
+		gtk_window_set_type_hint (GTK_WINDOW (pDialog), GDK_WINDOW_TYPE_HINT_DOCK);  // sinon le dialogue sera toujours derriere le sous-dock, meme avec un 'set_keep_above'. en contrepartie, le dialgue n'aura pas de bordure (du moins avec Compiz).
+		gtk_window_set_keep_above (GTK_WINDOW (pDialog), TRUE);
+		
 		gtk_widget_show_all (GTK_DIALOG (pDialog)->vbox);
 		gtk_window_set_position (GTK_WINDOW (pDialog), GTK_WIN_POS_CENTER_ALWAYS);
 		int answer = gtk_dialog_run (GTK_DIALOG (pDialog));
@@ -289,7 +301,31 @@ static void _cd_folders_launch_with (GtkMenuItem *pMenuItem, gpointer *app)
 {
 	Icon *icon = app[0];
 	gchar *cExec = app[3];
-	cairo_dock_launch_command_printf ("%s \"%s\"", NULL, cExec, icon->cBaseURI);  // en esperant que l'appli gere les URI...
+	gchar *cUri = NULL;
+	if (icon->cBaseURI && *icon->cBaseURI == '/')
+		cUri = g_filename_from_uri (icon->cBaseURI, NULL, NULL);
+	cairo_dock_launch_command_printf ("%s \"%s\"", NULL, cExec, cUri?cUri:icon->cBaseURI);  // in case the program doesn't handle URI (geeqie, etc).
+	g_free (cUri);
+}
+
+static void _cd_folders_sort_by_name (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+{
+	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_NAME);
+}
+
+static void _cd_folders_sort_by_date (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+{
+	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_DATE);
+}
+
+static void _cd_folders_sort_by_size (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+{
+	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_SIZE);
+}
+
+static void _cd_folders_sort_by_type (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+{
+	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_TYPE);
 }
 
 static void _free_app (gpointer *app)
@@ -319,8 +355,14 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	if (CD_APPLET_CLICKED_ICON == myIcon || CD_APPLET_CLICKED_ICON == NULL)  // click on main icon or on the container.
 	{
 		GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Open the folder (middle-click)"), GTK_STOCK_OPEN, _cd_folders_open_folder, CD_APPLET_MY_MENU, myApplet);
-		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
+		if (myConfig.bShowFiles)
+		{
+			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Open the folder"), D_("middle-click"));
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_OPEN, _cd_folders_open_folder, CD_APPLET_MY_MENU, myApplet);
+			g_free (cLabel);
+			if (pSubMenu == CD_APPLET_MY_MENU)
+				CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
+		}
 		CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 	}
 	else  // clic on a file.
@@ -363,8 +405,6 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 			}
 			g_list_free (pApps);
 		}
-		else
-			//g_print ("no apps list for '%s'\n", CD_APPLET_CLICKED_ICON->cBaseURI);
 		
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
 		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Properties"), GTK_STOCK_PROPERTIES, _cd_folders_show_file_properties, CD_APPLET_MY_MENU, data);
@@ -374,6 +414,12 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Create a new folder"), GTK_STOCK_NEW, _cd_folders_new_folder, CD_APPLET_MY_MENU, myApplet);
 	}
 	
+	GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Sort by"), CD_APPLET_MY_MENU, GTK_STOCK_SORT_DESCENDING);
+	pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By name"), _cd_folders_sort_by_name, pSubMenu, myApplet);
+	pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By date"), _cd_folders_sort_by_date, pSubMenu, myApplet);
+	pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By size"), _cd_folders_sort_by_size, pSubMenu, myApplet);
+	pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By type"), _cd_folders_sort_by_type, pSubMenu, myApplet);
+	
 	if (CD_APPLET_CLICKED_ICON != NULL && CD_APPLET_CLICKED_ICON != myIcon)
 		CD_APPLET_LEAVE (CAIRO_DOCK_INTERCEPT_NOTIFICATION);
 CD_APPLET_ON_BUILD_MENU_END
@@ -387,18 +433,18 @@ gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Ico
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	gchar *cPath = NULL;
-	if (strncmp (cReceivedData, "file://", 7) == 0)  // tous les programmes ne gerent pas les URI; pour parer au cas ou il ne le gererait pas, dans le cas d'un fichier local, on convertit en un chemin
+	if (strncmp (cReceivedData, "file://", 7) == 0)
 		cPath = g_filename_from_uri (cReceivedData, NULL, NULL);
 	else
 		cPath = g_strdup (cReceivedData);
 	
-	if (g_file_test (cPath, G_FILE_TEST_IS_DIR))
+	if (g_file_test (cPath, G_FILE_TEST_IS_DIR))  // it's a folder, let's add a new instance of the applet that will handle it.
 	{
 		//g_print (" ajout d'un repertoire...\n");
 		CairoDockModule *pModule = cairo_dock_find_module_from_name ("Folders");
 		g_return_val_if_fail (pModule != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 		
-		gchar *cConfFilePath = cairo_dock_add_module_conf_file (pModule);
+		gchar *cConfFilePath = cairo_dock_add_module_conf_file (pModule);  // we want to update the conf file before we instanciate the applet, so don't use high-level functions.
 		cairo_dock_update_conf_file (cConfFilePath,
 			G_TYPE_STRING, "Configuration", "dir path", cReceivedData,
 			G_TYPE_INVALID);
@@ -409,6 +455,12 @@ gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Ico
 			cairo_dock_update_dock_size (pNewInstance->pDock);
 		}
 		
+		if (pNewInstance != NULL)
+			cairo_dock_show_temporary_dialog_with_icon (D_("The folder has been imported."),
+				pNewInstance->pIcon, pNewInstance->pContainer,
+				5000,
+				MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);  // not "same icon" because the icon may not be loaded yet (eg. stack or emblem icon).
+		
 		if (pModule->pInstancesList && pModule->pInstancesList->next == NULL)  // module nouvellement active.
 		{
 			cairo_dock_write_active_modules ();
