@@ -34,7 +34,6 @@ void cd_shortcuts_get_fs_stat (const gchar *cDiskURI, CDDiskUsage *pDiskUsage)
 {
 	static struct statfs sts;
 	const gchar *cMountPath = (strncmp (cDiskURI, "file://", 7) == 0 ? cDiskURI + 7 : cDiskURI);
-	//g_print ("checking device on '%s'...\n", cMountPath);
 	
 	if (statfs (cMountPath, &sts) == 0)
 	{
@@ -66,7 +65,7 @@ static gboolean _cd_shortcuts_update_disk_usage (CairoDockModuleInstance *myAppl
 	for (ic = pIconsList; ic != NULL; ic = ic->next)
 	{
 		pIcon = ic->data;
-		if (pIcon->iType != CD_DRIVE_GROUP)  // les disques sont en 1er
+		if (pIcon->iGroup != CD_DRIVE_GROUP)  // les disques sont en 1er
 			break;
 		if (pIcon->cCommand != NULL)
 		{
@@ -143,14 +142,8 @@ void cd_shortcuts_launch_disk_periodic_task (CairoDockModuleInstance *myApplet)
 	}
 }
 
-void cd_shortcuts_stop_disk_periodic_task (CairoDockModuleInstance *myApplet)
-{
-	cairo_dock_stop_task (myData.pDiskTask);
-}
-
 void cd_shortcuts_free_disk_periodic_task (CairoDockModuleInstance *myApplet)
 {
-	cd_shortcuts_stop_disk_periodic_task (myApplet);
 	cairo_dock_free_task (myData.pDiskTask);
 	myData.pDiskTask = NULL;
 }
@@ -196,6 +189,7 @@ gchar *cd_shortcuts_get_disk_info (const gchar *cDiskURI, const gchar *cDiskName
 	GString *sInfo = g_string_new ("");
 	// on recupere les infos de taille.
 	CDDiskUsage diskUsage;
+	memset (&diskUsage, 0, sizeof (CDDiskUsage));
 	cd_shortcuts_get_fs_stat (cDiskURI, &diskUsage);
 	
 	// on recupere les infos du file system.
