@@ -126,7 +126,8 @@ static int _compare_icons_stack_order (Icon *icon1, Icon *icon2)
 }
 void cd_switcher_draw_main_icon_compact_mode (void)
 {
-	g_return_if_fail (myData.switcher.iNbColumns != 0 && myData.switcher.iNbLines != 0);
+	if (myData.switcher.iNbColumns == 0 || myData.switcher.iNbLines == 0)  // may happen in desklet mode with a cube desktop, when the desklet is still 0x0.
+		return;
 	g_return_if_fail (myDrawContext != NULL);
 	//g_print ("%s (%d;%d)\n", __func__, myData.switcher.iCurrentLine, myData.switcher.iCurrentColumn);
 	// On efface l'icone.
@@ -221,9 +222,9 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 	// chaque bureau/viewport.
 	int iNumDesktop=0, iNumViewportX=0, iNumViewportY=0;
 	int k = 0, N = g_desktopGeometry.iNbDesktops * g_desktopGeometry.iNbViewportX * g_desktopGeometry.iNbViewportY;
-	for (j = 0; j < myData.switcher.iNbLines; j ++)
+	for (j = 0; j < myData.switcher.iNbLines && k < N; j ++)
 	{
-		for (i = 0; i < myData.switcher.iNbColumns; i ++)
+		for (i = 0; i < myData.switcher.iNbColumns && k < N; i ++)
 		{
 			cairo_save (myDrawContext);
 
@@ -294,8 +295,6 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 				}
 			}
 			k ++;
-			if (k == N)
-				break ;
 		}
 	}
 	
